Module context

Module context 

Structs

ContextCache
Thread-local context cache with fast path for single Fory instance. Uses (cached_id, context) for O(1) access when using same Fory instance repeatedly. Falls back to HashMap for multiple Fory instances per thread.
ReadContext
Deserialization state container used on a single thread at a time. Sharing the same instance across threads simultaneously causes undefined behavior.
WriteContext
Serialization state container used on a single thread at a time. Sharing the same instance across threads simultaneously causes undefined behavior.