Struct ContextCache Copy item path Source pub struct ContextCache<T> { }Expand description Thread-local context cache with fast path for single Fory instance.
Uses (cached_id, context) for O(1) access when using same Fory instance repeatedly.
Falls back to HashMap for multiple Fory instances per thread.
Like get_or_insert, but the create closure returns a Result.
This allows error handling during context creation without pre-fetching resources.
Returns the “default value” for a type.
Read more Immutably borrows from an owned value.
Read more Mutably borrows from an owned value.
Read more Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From <T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.