ReadContext

Struct ReadContext 

pub struct ReadContext<'a> {
    pub reader: Reader<'a>,
    pub meta_resolver: MetaReaderResolver,
    pub ref_reader: RefReader,
    /* private fields */
}
Deserialization state container used on a single thread at a time. Sharing the same instance across threads simultaneously causes undefined behavior.

Fields

reader: Reader<'a>meta_resolver: MetaReaderResolverref_reader: RefReader

Implementations

Source

impl<'a> ReadContext<'a>

pub fn new(type_resolver: TypeResolver, config: Config) -> ReadContext<'a>

pub fn get_type_resolver(&self) -> &TypeResolver

Get type resolver

pub fn is_compatible(&self) -> bool

Check if compatible mode is enabled

pub fn is_share_meta(&self) -> bool

Check if meta sharing is enabled

pub fn is_xlang(&self) -> bool

Check if cross-language mode is enabled

pub fn is_check_struct_version(&self) -> bool

Check if class version checking is enabled

pub fn max_dyn_depth(&self) -> u32

Get maximum dynamic depth

pub fn attach_reader(&mut self, reader: Reader<'a>)

pub fn detach_reader(&mut self) -> Reader<'_>

pub fn get_type_info_by_index( &self, type_index: usize, ) -> Result<&Rc<TypeInfo>, Error>

pub fn get_meta(&self, type_index: usize) -> Result<&Rc<TypeInfo>, Error>

pub fn read_type_meta(&mut self) -> Result<Rc<TypeInfo>, Error>

Read type meta inline using streaming protocol. Returns the TypeInfo for this type.

pub fn read_any_type_info(&mut self) -> Result<Rc<TypeInfo>, Error>

pub fn get_type_info(&self, type_id: &TypeId) -> Result<Rc<TypeInfo>, Error>

pub fn read_meta_string(&mut self) -> Result<&MetaString, Error>

pub fn inc_depth(&mut self) -> Result<(), Error>

pub fn dec_depth(&mut self)

pub fn reset(&mut self)