ArrayView

Struct ArrayView 

pub struct ArrayView<'a, T: RowValue> { /* private fields */ }
A zero-copy view over one Standard Row Format array.

Implementations

Source

impl<'a, T: RowValue> ArrayView<'a, T>

pub fn len(&self) -> usize

Returns the number of elements encoded in this array.

pub fn is_empty(&self) -> bool

Returns true when this array contains no elements.

pub fn iter(&self) -> ArrayIter<'_, 'a, T>

Returns an iterator that reads elements on demand.

pub fn get(&self, index: usize) -> Result<T::View<'a>, Error>

Reads one array element without materializing the rest of the array.

pub fn is_null(&self, index: usize) -> Result<bool, Error>

Returns whether an element’s null bit is set.