MapView

Struct MapView 

pub struct MapView<'a, K: RowValue, V: RowValue> { /* private fields */ }
A zero-copy view over one Standard Row Format map.

Implementations

Source

impl<'a, K: RowValue, V: RowValue> MapView<'a, K, V>

pub fn len(&self) -> usize

Returns the number of key-value pairs encoded in this map.

pub fn is_empty(&self) -> bool

Returns true when this map contains no key-value pairs.

pub fn key(&self, index: usize) -> Result<K::View<'a>, Error>

Reads the key at index without materializing the map.

pub fn value(&self, index: usize) -> Result<V::View<'a>, Error>

Reads the value at index without materializing the map.

pub fn keys(&self) -> &ArrayView<'a, K>

Returns the map’s key array.

pub fn values(&self) -> &ArrayView<'a, V>

Returns the map’s value array.

pub fn to_btree_map( &self, ) -> Result<BTreeMap<<K as RowValue>::View<'a>, <V as RowValue>::View<'a>>, Error>
where <K as RowValue>::View<'a>: Ord,

Materializes this view as a BTreeMap.