RowView

Trait RowView 

pub trait RowView<'a> {
    // Required method
    fn as_bytes(&self) -> &'a [u8] ;

    // Provided method
    fn encoded_len(&self) -> usize { ... }
}
Backing-byte access shared by immutable Standard Row Format views.

Required Methods

fn as_bytes(&self) -> &'a [u8]

Returns the complete encoded bytes bound to this view.

Provided Methods

fn encoded_len(&self) -> usize

Returns the number of encoded bytes bound to this view.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<'a, K: RowValue, V: RowValue> RowView<'a> for MapView<'a, K, V>

Source

impl<'a, T: RowValue> RowView<'a> for ArrayView<'a, T>