Module serializer

Module serializer 

Re-exports

pub use any::read_box_any;
pub use any::write_box_any;

Modules

any
collection
enum_
map
skip
struct_
trait_object
util
weak
Serialization support for crate::types::weak::RcWeak and crate::types::weak::ArcWeak.

Traits

ForyDefault
Trait for creating default values during Fory deserialization.
Serializer
Core trait for Fory serialization and deserialization.
StructSerializer
Extended trait for struct and enum serialization.

Functions

read_data
Deserializes an object implementing Serializer from the read context.
write_data
Serializes an object implementing Serializer to the write context.