Module map

Module map 

Structs

BTreeMapCodec
BTreeMapSerializer
Statically serializes BTreeMap<KS::Target, VS::Target> at roots or recursive carrier nodes. This zero-sized carrier composes its key and value serializers and is not registered independently.
HashMapCodec
HashMapSerializer
Statically serializes HashMap<KS::Target, VS::Target> at roots or recursive carrier nodes. This zero-sized carrier composes its key and value serializers and is not registered independently.