pub struct HashMapCodec<K, V, KC, VC, const NULLABLE: bool, const TRACK_REF: bool>(/* private fields */);Trait Implementations
Sourceimpl<K, V, KS, VS, const NULLABLE: bool, const TRACK_REF: bool> Serializer for HashMapCodec<K, V, KS, VS, NULLABLE, TRACK_REF>
impl<K, V, KS, VS, const NULLABLE: bool, const TRACK_REF: bool> Serializer for HashMapCodec<K, V, KS, VS, NULLABLE, TRACK_REF>
type Target = HashMap<K, V>
Sourcefn write_data(
value: &Self::Target,
context: &mut WriteContext<'_>,
) -> Result<(), Error>
fn write_data( value: &Self::Target, context: &mut WriteContext<'_>, ) -> Result<(), Error>
Write the target body only.
Sourcefn read_data(context: &mut ReadContext<'_>) -> Result<Self::Target, Error>
fn read_data(context: &mut ReadContext<'_>) -> Result<Self::Target, Error>
Read the target body only.
Sourcefn default_value(_: &mut ReadContext<'_>) -> Result<Self::Target, Error>
fn default_value(_: &mut ReadContext<'_>) -> Result<Self::Target, Error>
Construct a target for a null or missing local value.
Sourcefn read_arc_any(
context: &mut ReadContext<'_>,
) -> Result<Arc<dyn Any + Send + Sync>, Error>
fn read_arc_any( context: &mut ReadContext<'_>, ) -> Result<Arc<dyn Any + Send + Sync>, Error>
Read directly into the final owner for sync dynamic carriers.