Functions
- field_
need_ read_ type_ info - Check at runtime whether type info should be skipped for a given type id.
- field_
need_ write_ ref_ into - Keep as const fn for compile time evaluation or constant folding
- field_
need_ write_ type_ info - Keep as const fn for compile time evaluation or constant folding
- write_
dyn_ data_ generic