pub struct RcWeakCodec<T, C, const NULLABLE: bool, const TRACK_REF: bool>(/* private fields */);Trait Implementations
Sourceimpl<T, C, const NULLABLE: bool, const TRACK_REF: bool> Serializer for RcWeakCodec<T, C, NULLABLE, TRACK_REF>where
T: 'static,
C: Serializer<Target = T>,
impl<T, C, const NULLABLE: bool, const TRACK_REF: bool> Serializer for RcWeakCodec<T, C, NULLABLE, TRACK_REF>where
T: 'static,
C: Serializer<Target = T>,
type Target = RcWeak<T>
Sourcefn write_data(_: &RcWeak<T>, _: &mut WriteContext<'_>) -> Result<(), Error>
fn write_data(_: &RcWeak<T>, _: &mut WriteContext<'_>) -> Result<(), Error>
Write the target body only.
Sourcefn default_value(context: &mut ReadContext<'_>) -> Result<RcWeak<T>, Error>
fn default_value(context: &mut ReadContext<'_>) -> Result<RcWeak<T>, Error>
Construct a target for a null or missing local value.
Sourcefn read_arc_any(
context: &mut ReadContext<'_>,
) -> Result<Arc<dyn Any + Send + Sync>, Error>
fn read_arc_any( context: &mut ReadContext<'_>, ) -> Result<Arc<dyn Any + Send + Sync>, Error>
Read directly into the final owner for sync dynamic carriers.