Module context
fory_
core
0.15.0
Module context
Module Items
Structs
In fory_
core::
resolver
fory_core
::
resolver
Module
context
Structs

Context
Cache
Thread-local context cache with fast path for single Fory instance. Uses (cached_id, context) for O(1) access when using same Fory instance repeatedly. Falls back to HashMap for multiple Fory instances per thread.
Read
Context
Deserialization state container used on a single thread at a time. Sharing the same instance across threads simultaneously causes undefined behavior.
Write
Context
Serialization state container used on a single thread at a time. Sharing the same instance across threads simultaneously causes undefined behavior.