Module context

Module context 

Structs

Pool
ReadContext
Deserialization state container used on a single thread at a time. Sharing the same instance across threads simultaneously causes undefined behavior.
WriteContext
Serialization state container used on a single thread at a time. Sharing the same instance across threads simultaneously causes undefined behavior.