Structs
- Pool
- Read
Context - Deserialization state container used on a single thread at a time. Sharing the same instance across threads simultaneously causes undefined behavior.
- Write
Context - Serialization state container used on a single thread at a time. Sharing the same instance across threads simultaneously causes undefined behavior.