Skip to main contentModule row
Source - ArrayIter
- An iterator over the elements of an
ArrayView. - ArrayView
- A zero-copy view over one Standard Row Format array.
- MapView
- A zero-copy view over one Standard Row Format map.
- Row
- A self-contained Standard Row Format root.
- RowView
- Backing-byte access shared by immutable Standard Row Format views.
- from_row
- Decodes a Standard Row Format struct, array, or map root.
- to_row
- Encodes a struct, array, or map as a Standard Row Format root.
- to_row_into
- Replaces
buffer with one encoded Standard Row Format root.