pub trait RowView<'a> {
// Required method
fn as_bytes(&self) -> &'a [u8] ⓘ;
// Provided method
fn encoded_len(&self) -> usize { ... }
}Expand description
Backing-byte access shared by immutable Standard Row Format views.
Required Methods
Provided Methods
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the number of encoded bytes bound to this view.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".